summaryrefslogtreecommitdiff
path: root/src/wasm-io.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/wasm-io.h')
-rw-r--r--src/wasm-io.h6
1 files changed, 5 insertions, 1 deletions
diff --git a/src/wasm-io.h b/src/wasm-io.h
index 2dfdbae6c..6d8dcc6e5 100644
--- a/src/wasm-io.h
+++ b/src/wasm-io.h
@@ -42,11 +42,15 @@ public:
// read binary
void readBinary(std::string filename, Module& wasm,
std::string sourceMapFilename="");
// read text or binary, checking the contents for what it is
void read(std::string filename, Module& wasm,
std::string sourceMapFilename="");
// check whether a file is a wasm binary
bool isBinaryFile(std::string filename);
+
+private:
+ void readStdin(Module& wasm, std::string sourceMapFilename);
};
class ModuleWriter : public ModuleIO {
@@ -42,11 +42,15 @@ public:
void readBinary(std::string filename, Module& wasm,
std::string sourceMapFilename="");
- // read text or binary, checking the contents for what it is
+ // read text or binary, checking the contents for what it is. If `filename` is
+ // empty, read from stdin.
void read(std::string filename, Module& wasm,
std::string sourceMapFilename="");